committer

package
v0.0.0-...-fd95878 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Committer

type Committer struct {
	// contains filtered or unexported fields
}

func NewCommitter

func NewCommitter(ctx context.Context, db *storage.VersionedDB, channel string, peer *comm.Peer, signer fabrictx.Signer, logger Logger) (*Committer, error)

func (*Committer) BlockHeight

func (c *Committer) BlockHeight() (uint64, error)

func (*Committer) PeerBlockHeight

func (c *Committer) PeerBlockHeight() (uint64, error)

func (*Committer) Run

func (c *Committer) Run() error

func (*Committer) Stop

func (c *Committer) Stop()

func (*Committer) WaitUntilSynced

func (c *Committer) WaitUntilSynced(ctx context.Context) error

WaitUntilSynced blocks until the committer has processed all blocks up to the peer's current height. Returns an error if the context is canceled or times out.

type Logger

type Logger interface {
	Printf(format string, v ...any)
}

Jump to